pub struct MockSubprocessRuntime { /* private fields */ }Expand description
Mock subprocess runtime for testing.
Implementations
Sourceimpl MockSubprocessRuntime
impl MockSubprocessRuntime
Sourcepub fn add_response(&self, response: MockResponse)
pub fn add_response(&self, response: MockResponse)
Add a response to be returned for the next command.
Sourcepub fn set_default_response(&mut self, response: MockResponse)
pub fn set_default_response(&mut self, response: MockResponse)
Set the default response when no queued responses remain.
Sourcepub fn invocations(&self) -> Vec<CommandInvocation>
pub fn invocations(&self) -> Vec<CommandInvocation>
Get all recorded invocations.
Sourcepub fn clear_invocations(&self)
pub fn clear_invocations(&self)
Clear recorded invocations.